@@ -7,7 +7,7 @@ import logging
 logging.basicConfig(level=logging.INFO)
 
 bed_file = '../data/mouse_long/plink'
-#agmat(bed_file, out_file='../data/mouse_long/test', out_fmt='id_id_val')
+agmat(bed_file, out_file='../data/mouse_long/test', out_fmt='id_id_val')
 data_file = '../data/mouse_long/phe.unbalance.txt'
 id = 'ID'
 tpoint = 'weak'
@@ -15,7 +15,10 @@ trait = 'trait'
 agmat_file = '../data/mouse_long/test'
 tfix = 'Sex'
 prefix_outfile = '../data/mouse_long/unbalance_varcom'
-#res_var = unbalance_varcom(data_file, id, tpoint, trait, agmat_file, tfix="Sex", out_file=prefix_outfile)
+res_var = unbalance_varcom(data_file, id, tpoint, trait, agmat_file, tfix=None, out_file=prefix_outfile)
+res_var = unbalance_varcom(data_file, id, tpoint, trait, agmat_file, tfix="Sex", out_file=prefix_outfile + '.tSex')
+res_var = unbalance_varcom(data_file, id, tpoint, trait, agmat_file, fix="Sex", out_file=prefix_outfile + '.Sex')
+
 #print(res_var)
 
 
