@@ -19,7 +19,7 @@ from ._pre_data import _pre_data
 from ._common import _design_matrix, _leg_mt, _full_col_rank
 
 
-def unbalance_longwas_fixed_(data_file, id, tpoint, trait, bed_file, agmat_file, var_com, condition_snp=None, snp_lst=None,
+def unbalance_longwas_fixed(data_file, id, tpoint, trait, bed_file, agmat_file, var_com, condition_snp=None, snp_lst=None,
             tfix=None, fix=None, forder=3, aorder=3, porder=3, na_method='omit',
                              prefix_outfile='unbalance_longwas_fixed'):
     """
