@@ -20,7 +20,7 @@ from ._common import _design_matrix, _leg_mt
 
 
 def unbalance_longwas_trans_permutation(data_file, id, tpoint, trait, bed_file, agmat_file, var_com, permutation_lst=None, snp_lst=None,
-            tfix=None, fix=None, forder=3, aorder=3, porder=3, na_method='omit', crank=False,
+            tfix=None, fix=None, forder=3, aorder=3, porder=3, na_method='omit',
                              prefix_outfile='unbalance_longwas_trans_permutation'):
     """
     the longitudinal GWAS for the unbalanced data treating the SNP as the time varied random effect.
@@ -45,7 +45,6 @@ def unbalance_longwas_trans_permutation(data_file, id, tpoint, trait, bed_file,
     :param porder: the order of Legendre polynomials for the permanent environment effect. The default value is 3.
     :param na_method: The method to deal with missing values. The default value is 'omit'. 'omit' method will delete the
     row with missing values. 'include' method will fill the missing values with the adjacent values.
-    :param crank: force the column full rank of fixed effects. Default is False.
     :param prefix_outfile: the prefix for the output file. Default is 'unbalance_longwas_fixed'.
     :return: A pandas data frame for the test result.
     """
@@ -75,9 +74,8 @@ def unbalance_longwas_trans_permutation(data_file, id, tpoint, trait, bed_file,
     if fix is not None:
         xmat_nt = _design_matrix(fix, data_df)
         xmat = np.concatenate([xmat_t, xmat_nt[:, 1:]], axis=1)
-    if crank:
-        _, indexes = sympy.Matrix(xmat).rref()
-        xmat = xmat[:, indexes]
+    if np.linalg.matrix_rank(xmat) < xmat.shape[1]:
+        xmat = _full_col_rank(xmat)
     logging.info('***Build the dedign matrix for random effect***')
     logging.info('Legendre order for additive effects: {}'.format(aorder))
     leg_add = _leg_mt(data_df[tpoint], tmax, tmin, aorder)
