@@ -70,16 +70,8 @@ def fixed(pheno_file, bed_file, agmat_file, class_lst=None, fix=None, out_file='
     maxiter = maxiter1
     if not convergence:
         maxiter = 0
+    vmat = 1.0 / (gmat_eigenvals * var[0] + var[1])
     if speed:  # whether to speed up with estimated variances in the null model
-        vmat = 1.0 / (gmat_eigenvals * var[0] + var[1])
-        vx = np.multiply(vmat, xmat_trans)
-        xvx = np.dot(xmat_trans.T, vx)
-        xvx = linalg.inv(xvx)
-        # py
-        pmat = -np.dot(np.dot(vx, xvx), vx.T)
-        diag_val = np.diag(pmat)
-        np.fill_diagonal(pmat, diag_val + vmat[:, -1])
-        py = np.dot(pmat, y_trans)
         for i in range(npart):
             logging.info('The {}/{} part'.format(i + 1, npart))
             snp_info = pd.read_csv(bed_file + '.bim', sep='\s+', header=None, skiprows=snp_index[i],
@@ -90,12 +82,31 @@ def fixed(pheno_file, bed_file, agmat_file, class_lst=None, fix=None, out_file='
             if np.any(np.isnan(snp_mat)):
                 snp_mat = impute_geno(snp_mat)
             snp_mat = np.dot(gmat_eigenvecs.T, snp_mat)
-            se_arr = np.sum(np.multiply(snp_mat, np.dot(pmat, snp_mat)), axis=0)
-            se_arr = 1/se_arr
-            eff_arr = np.dot(snp_mat.T, py)[:, -1]
-            p_arr = chi2.sf(eff_arr * eff_arr * se_arr, 1)
-            eff_arr = eff_arr * se_arr
-            se_arr = np.sqrt(se_arr)
+            eff_vec = []
+            se_vec = []
+            p_vec = []
+            for k in tqdm(range(snp_mat.shape[1])):
+                xmat_trans_k = np.concatenate([xmat_trans, snp_mat[:, k:(k + 1)]], axis=1)
+                vx = np.multiply(vmat, xmat_trans_k)
+                xvx = np.dot(xmat_trans_k.T, vx)
+                try:
+                    xvx = linalg.inv(xvx)
+                except Exception as _:
+                    xvx = np.diag(np.diag(xvx)) * 0.001 + xvx
+                    xvx = linalg.inv(xvx)
+                # py
+                xvy = np.dot(vx.T, y_trans)
+                b_hat = np.dot(xvx, xvy)
+                snp_eff = b_hat[-1, -1]
+                se = np.sqrt(xvx[-1, -1])
+                t_val = snp_eff / se
+                p_val = chi2.sf(t_val * t_val, 1)
+                eff_vec.append(snp_eff)
+                se_vec.append(se)
+                p_vec.append(p_val)
+            eff_arr = np.array(eff_vec)
+            se_arr = np.array(se_vec)
+            p_arr = np.array(p_vec)
             cc_arr = np.array([1000.0]*len(se_arr))
             ind_bool = p_arr < pcut
             cc_vec = []
@@ -104,8 +115,7 @@ def fixed(pheno_file, bed_file, agmat_file, class_lst=None, fix=None, out_file='
             p_vec = []
             snp_mat = snp_mat[:, ind_bool]
             for k in tqdm(range(snp_mat.shape[1])):
-                snpk = snp_mat[:, k:(k + 1)]
-                xmat_trans_k = np.concatenate([xmat_trans, snpk], axis=1)
+                xmat_trans_k = np.concatenate([xmat_trans, snp_mat[:, k:(k + 1)]], axis=1)
                 cc_val, snp_eff, se, p_val = _weight_emai_eigen_snp(y_trans, xmat_trans_k, gmat_eigenvals, var,
                                                                     maxiter=maxiter, cc=1.0e-8)
                 cc_vec.append(cc_val)
@@ -120,7 +130,7 @@ def fixed(pheno_file, bed_file, agmat_file, class_lst=None, fix=None, out_file='
             res_df.loc[:, 'eff_val'] = eff_arr
             res_df.loc[:, 'se_val'] = se_arr
             res_df.loc[:, 'p_val'] = p_arr
-            res_df.to_csv(out_file, sep='\t', index=False, header=False, mode='a')
+            res_df.to_csv(out_file, sep='\t', index=False, header=False, mode='a', na_rep='NA')
     else:
         for i in range(npart):
             logging.info('The {}/{} part'.format(i + 1, npart))
@@ -137,8 +147,7 @@ def fixed(pheno_file, bed_file, agmat_file, class_lst=None, fix=None, out_file='
             se_vec = []
             p_vec = []
             for k in tqdm(range(snp_mat.shape[1])):
-                snpk = snp_mat[:, k:(k + 1)]
-                xmat_trans_k = np.concatenate([xmat_trans, snpk], axis=1)
+                xmat_trans_k = np.concatenate([xmat_trans, snp_mat[:, k:(k + 1)]], axis=1)
                 cc_val, snp_eff, se, p_val = _weight_emai_eigen_snp(y_trans, xmat_trans_k, gmat_eigenvals, var,
                                                                     maxiter=maxiter, cc=1.0e-8)
                 cc_vec.append(cc_val)
@@ -149,7 +158,7 @@ def fixed(pheno_file, bed_file, agmat_file, class_lst=None, fix=None, out_file='
             res_df.loc[:, 'eff_val'] = eff_vec
             res_df.loc[:, 'se_val'] = se_vec
             res_df.loc[:, 'p_val'] = p_vec
-            res_df.to_csv(out_file, sep='\t', index=False, header=False, mode='a')
+            res_df.to_csv(out_file, sep='\t', index=False, header=False, mode='a', na_rep='NA')
     return 0
 
 
@@ -290,7 +299,11 @@ def _weight_emai_eigen_snp(y_trans, xmat_trans, gmat_eigenvals, var, maxiter=20,
         vmat = 1.0 / (gmat_eigenvals * var[0] + var[1])
         vx = np.multiply(vmat, xmat_trans)
         xvx = np.dot(xmat_trans.T, vx)
-        xvx = linalg.inv(xvx)
+        try:
+            xvx = linalg.inv(xvx)
+        except Exception as _:
+            xvx = np.diag(np.diag(xvx)) * 0.001 + xvx
+            xvx = linalg.inv(xvx)
         # py
         xvy = np.dot(vx.T, y_trans)
         y_xb = y_trans - np.dot(xmat_trans, np.dot(xvx, xvy))
@@ -343,7 +356,11 @@ def _weight_emai_eigen_snp(y_trans, xmat_trans, gmat_eigenvals, var, maxiter=20,
     vmat = 1.0 / (gmat_eigenvals * var[0] + var[1])
     vx = np.multiply(vmat, xmat_trans)
     xvx = np.dot(xmat_trans.T, vx)
-    xvx = linalg.inv(xvx)
+    try:
+        xvx = linalg.inv(xvx)
+    except Exception as _:
+        xvx = np.diag(np.diag(xvx)) * 0.001 + xvx
+        xvx = linalg.inv(xvx)
     # py
     xvy = np.dot(vx.T, y_trans)
     b_hat = np.dot(xvx, xvy)
